@@ -34,7 +34,7 @@ class Orden(BaseModel):
     op_tc_clave_ord: types.TipoCuentaOrdenPago = None
     op_cuenta_ord: str = None
     op_rfc_curp_ord: str = None
-    op_ins_clave_ord: digits(3, 5)
+    op_ins_clave_ord: digits(3, 5) = None
     # destination info
     op_nom_ben: str = None
     op_tc_clave_ben: types.TipoCuentaOrdenPago = None
@@ -115,7 +115,7 @@ class Orden(BaseModel):
 
         elements = self.dict(
             exclude_none=True,
-            exclude={'id', 'categoria', 'op_ins_clave_ord'},
+            exclude={'id', 'categoria', 'op_ins_clave_ben'},
         )
 
         for element, value in elements.items():  # noqa: WPS110
@@ -124,7 +124,7 @@ class Orden(BaseModel):
                     subelement = etree.SubElement(ordenpago, 'opFirmaDig')
                     subelement.text = str(value)
                     continue
-                if element == 'op_ins_clave_ben':
+                if element == 'op_ins_clave_ord':
                     subelement = etree.SubElement(ordenpago, 'OpInsClave')
                     subelement.text = str(value)
                     continue
@@ -135,12 +135,7 @@ class Orden(BaseModel):
         return ordenpago
 
     @classmethod
-    def parse_xml(
-        cls,
-        orden_element,
-        categoria: types.CategoriaOrdenPago,
-        origin_institution: types.ClaveOrdenanteOrdenPago = None,
-    ):
+    def parse_xml(cls, orden_element, categoria: types.CategoriaOrdenPago):
         orden_data = {
             'id': orden_element.attrib['Id'],
             'categoria': categoria,
@@ -151,10 +146,7 @@ class Orden(BaseModel):
             if tag in cls.__fields__:
                 orden_data[tag] = element.text
             if tag == 'op_ins_clave':
-                orden_data['op_ins_clave_ben'] = element.text
-
-        if 'op_ins_clave_ord' not in orden_data:
-            orden_data['op_ins_clave_ord'] = origin_institution
+                orden_data['op_ins_clave_ord'] = element.text
 
         return cls(**orden_data)
 
